#include "PokktCocosManager.h"

// pokkt event definitions
const std::string PokktCocosManager::VideoClosedEvent = "videoClosed";
const std::string PokktCocosManager::VideoDisplayedEvent = "videoDisplayed";
const std::string PokktCocosManager::VideoSkippedEvent = "videoSkipped";
const std::string PokktCocosManager::VideoCompletedEvent = "videoCompleted";
const std::string PokktCocosManager::VideoGratifiedEvent = "videoGratified";
const std::string PokktCocosManager::DownloadCompletedEvent = "downloadCompleted";
const std::string PokktCocosManager::DownloadFailedEvent = "downloadFailed";
const std::string PokktCocosManager::CoinResponseEvent = "coinResponse";
const std::string PokktCocosManager::CoinResponseWithTransIdEvent = "coinResponseWithTrId";
const std::string PokktCocosManager::CoinResponseFailedEvent = "coinResponseFailed";
const std::string PokktCocosManager::CampaignAvailabilityEvent = "campaignAvailability";
const std::string PokktCocosManager::OfferwallClosedEvent = "offerwallClosedEvent";


bool PokktCocosManager::_isDebugEnabled = true;

std::map<std::string, PokktCocosManager::ListenerTargetPair*> PokktCocosManager::_eventMap;

void PokktCocosManager::handleNativeMessage(std::string operation, std::string param)
{
    POKKTLOG("[POKKT-CPP] message received! operation: %s, param: %s", operation.c_str(), param.c_str());
    
    ListenerTargetPair *l = _eventMap[operation];
    if (l != NULL)
    {
        EVT_SELECTOR listener = l->listener;
        cocos2d::CCObject *target = l->target;
        (target->*listener)(param);
    }
}

void PokktCocosManager::setListener(std::string eventName, EVT_SELECTOR listener, cocos2d::CCObject *target)
{
    ListenerTargetPair *pair = new ListenerTargetPair();
    pair->listener = listener;
    pair->target = target;
    _eventMap[eventName] = pair;
}

void PokktCocosManager::removeListener(std::string eventName)
{
    CC_SAFE_DELETE(_eventMap[eventName]);
    _eventMap[eventName] = NULL;
}

// Common methods

void PokktCocosManager::initPokkt()
{
    PokktNativeExtension::performOperation(PokktNativeExtension::InitPokkt);
}

void PokktCocosManager::setDebug(bool value)
{
    _isDebugEnabled = value;
    
    PokktNativeExtension::performOperation(PokktNativeExtension::SetDebug, _isDebugEnabled ? "true" : "false");
}

bool PokktCocosManager::getDebug()
{
    return _isDebugEnabled;
}

void PokktCocosManager::showLog(std::string message)
{
    PokktNativeExtension::performOperation(PokktNativeExtension::ShowLog, message);
}

void PokktCocosManager::showToast(std::string message)
{
    PokktNativeExtension::performOperation(PokktNativeExtension::ShowToast, message);
}

void PokktCocosManager::exportLog()
{
    PokktNativeExtension::performOperation(PokktNativeExtension::ExportLog);
}

void PokktCocosManager::sendAppInfo()
{
    PokktNativeExtension::performOperation(PokktNativeExtension::SendAppInfo);
}

// Session methods

void PokktCocosManager::startSession()
{
    PokktNativeExtension::performOperation(PokktNativeExtension::StartSession);
}
void PokktCocosManager::endSession()
{
    PokktNativeExtension::performOperation(PokktNativeExtension::EndSession);
}

// OfferWall methods

void PokktCocosManager::getCoins(PokktCocosConfig *pokktCocosConfig)
{
    PokktNativeExtension::performOperation(PokktNativeExtension::GetCoins, pokktCocosConfig->getOfferWallAssetValue());
}

void PokktCocosManager::getPendingCoins()
{
    PokktNativeExtension::performOperation(PokktNativeExtension::GetPendingCoins);
}

void PokktCocosManager::checkOfferWallCampaign()
{
    PokktNativeExtension::performOperation(PokktNativeExtension::CheckOfferWallCampaign);
}

// Video methods

void PokktCocosManager::getVideo(PokktCocosConfig *pokktCocosConfig)
{
    pokktCocosConfig->setIncentivised(true);
    PokktNativeExtension::performOperation(PokktNativeExtension::GetVideo, pokktCocosConfig->getScreenName());
}

void PokktCocosManager::getVideoNonIncent(PokktCocosConfig *pokktCocosConfig)
{
    pokktCocosConfig->setIncentivised(false);
    PokktNativeExtension::performOperation(PokktNativeExtension::GetVideoNonIncent, pokktCocosConfig->getScreenName());
}

void PokktCocosManager::cacheVideoCampaign()
{
    PokktNativeExtension::performOperation(PokktNativeExtension::CacheVideoCampaign);
}

bool PokktCocosManager::isVideoAvailable()
{
    return PokktNativeExtension::isVideoAvailable();
}

double PokktCocosManager::getVideoVc()
{
    return PokktNativeExtension::getVideoVc();
}

// Optional methods

std::string PokktCocosManager::getVersion()
{
    return PokktNativeExtension::getPokktSDKVersion();
}
