//
//  AppLovin.m
//  SampleApp
//
//  Created by Pokkt on 10/8/15.
//  Copyright © 2015 Pokkt. All rights reserved.
//

#import "AppLovin.h"
#import "ALSdk.h"
#import "ALInterstitialAd.h"
#import "ALIncentivizedInterstitialAd.h"
#import "PokktNetworkDelegate.h"
#import "NetworkModel.h"
#import "PokktManager.h"

@implementation AppLovin

static BOOL isInitialized;

ALInterstitialAd *interstitial;
NetworkModel *network;
static NSString *rewardAmount;

@synthesize networkName;

- (instancetype)init
{
    self = [super init];
    if (self)
    {
        
    }
    return self;
}

- (void)initNetwork:(PokktConfig *)pokktConfig networkModel:(NetworkModel *)customData
presentingViewController:(UIViewController *)viewController
{
    if (isInitialized) {
        return;
    }
    
    self.pokktConfig = pokktConfig;
    network = customData;
    [ALSdk initializeSdk];
    isInitialized = YES;
    self.isVideoCached = NO;
    self.isTimedout = NO;
    
    NSLog(@"[APP-LOVIN]APP Lovin Initialised");
}

- (void)cacheVideo
{
    NSString *str = nil;
    if (self.isVideoCached)
    {
        str = @"[APP-LOVIN] App Lovin video were already saved in cached";
        self.isVideoCached = NO;
        [PokktNetworkDelegate didFinishedVideoDownload:self.pokktConfig networkModel:network rewardValue:0 downLoadTime:@""];
    }
    else
    {
        [ALIncentivizedInterstitialAd shared].adDisplayDelegate = self;
        [ALIncentivizedInterstitialAd shared].adVideoPlaybackDelegate = self;
        [[ALIncentivizedInterstitialAd shared] preloadAndNotify: self];
        
        self.isTimedout = NO;
        int cacheTimeoutInterval = [PokktManager getCachingTimeoutDuration:network];
        self.cacheTimer = [NSTimer scheduledTimerWithTimeInterval:cacheTimeoutInterval target:self selector:@selector(updateTimer) userInfo:nil repeats:NO];
        str = @"[APP-LOVIN] App Lovin video caching start with timeout timer";
        
        
    }
    NSLog(@"%@",str);
}

- (void)playVideo
{
    [ALIncentivizedInterstitialAd showAndNotify:self];
    NSLog(@"[APP-LOVIN]APP Lovin Video Play");
}

- (void)updateTimer
{
    if (self.cacheTimer)
    {
        [self.cacheTimer invalidate];
        self.cacheTimer = nil;
        self.isTimedout = YES;
        
        [PokktNetworkDelegate didFailedVideoDownload:self.pokktConfig networkModel:network errorMessage:@"timed out"];
        NSLog(@"[APP-LOVIN]APP Lovin Video caching request timeout due to low network.");
    }
}


#pragma mark - Ad Load Delegate

-(void) ad: (alnonnull ALAd *) ad wasDisplayedIn: (alnonnull UIView *) view
{
    [self log: @"[APP-LOVIN] Rewarded video loaded"];
}

-(void) ad: (alnonnull ALAd *) ad wasHiddenIn: (alnonnull UIView *) view
{
    [self log: @"[APP-LOVIN] Rewarded video loaded"];
    [PokktNetworkDelegate onVideoClosed:self.pokktConfig networkModel:network];
}

- (void)adService:(ALAdService *)adService didLoadAd:(ALAd *)ad
{
    NSString *str = nil;
    if (self.isTimedout)
    {
        str = @"[APP-LOVIN] timeOut";
        self.isVideoCached = YES;
    }
    else
    {
        self.isVideoCached = NO;
        
        str = @"[APP-LOVIN] Video downloaded";
        [self.cacheTimer invalidate];
        self.cacheTimer = nil;
        [PokktNetworkDelegate didFinishedVideoDownload:self.pokktConfig networkModel:network rewardValue:0 downLoadTime:@""];
    }
    [self log: str];
}

-(void) ad: (alnonnull ALAd *) ad wasClickedIn: (alnonnull UIView *) view
{
    [self log: @"Clicked on Rewarded video"];
}

- (void)adService:(ALAdService *)adService didFailToLoadAdWithError:(int)code
{
    NSString *str = [NSString stringWithFormat: @"[APP-LOVIN] Rewarded video failed to load with error code %d", code];
    
    self.isVideoCached = NO;
    
    if (self.isTimedout)
    {
        str = [NSString stringWithFormat: @"[APP-LOVIN] Time out and Rewarded video failed to load with error code %d", code];
    }
    else
    {
        [self.cacheTimer invalidate];
        self.cacheTimer = nil;
        [PokktNetworkDelegate didFailedVideoDownload:self.pokktConfig networkModel:network errorMessage:str];
    }
    [self log: str];
}

#pragma mark - Ad Reward Delegate

- (void)rewardValidationRequestForAd:(ALAd *)ad didSucceedWithResponse:(nonnull NSDictionary *)response
{
    rewardAmount = [response objectForKey:@"amount"];
}

-(void) rewardValidationRequestForAd: (alnonnull ALAd*) ad didExceedQuotaWithResponse: (alnonnull NSDictionary*) response
{
    NSLog(@"%@",response);
}

-(void) rewardValidationRequestForAd: (alnonnull ALAd*) ad wasRejectedWithResponse: (alnonnull NSDictionary*) response
{
    NSLog(@"%@",response);
}

-(void) rewardValidationRequestForAd: (alnonnull ALAd*) ad didFailWithError: (NSInteger) responseCode
{
    NSLog(@"%ld",(long)responseCode);
}


#pragma mark - Ad Video Playback Delegate

- (void)videoPlaybackBeganInAd:(alnonnull ALAd *)ad
{
    [self log: @"[APP-LOVIN] Video Started"];
    [PokktNetworkDelegate onVideoDisplayed:self.pokktConfig networkModel:network];
    
}

- (void)videoPlaybackEndedInAd:(alnonnull ALAd *)ad atPlaybackPercent:(alnonnull NSNumber *)percentPlayed fullyWatched:(BOOL)wasFullyWatched
{
    [self log: @"[APP-LOVIN] Video Ended"];
    if (wasFullyWatched) {
        [PokktNetworkDelegate onVideoCompleted:self.pokktConfig networkModel:network];
        [PokktNetworkDelegate onVideoGratified:self.pokktConfig networkModel:network rewardPoint:[rewardAmount floatValue]];
    }
    
    
    
}

- (void)log:(NSString *)message
{
    dispatch_async(dispatch_get_main_queue(), ^{
        
        NSLog(@"[%@] : %@", NSStringFromClass([self class]), message);
    });
}

@end
