//
//  ChartboostNetwork.m
//  SampleApp
//
//  Created by Subhendu Sekhar Sahu on 08/10/15.
//  Copyright © 2015 Pokkt. All rights reserved.
//

#import "ChartboostNetwork.h"
#import "PokktNetworkDelegate.h"
#import "PokktManager.h"

@implementation ChartboostNetwork

static NSString *networkType = @"ChartBoost";

- (instancetype)init
{
    self = [super init];
    if (self)
    {
        
    }
    return self;
}

- (void) initNetwork:(PokktConfig *)pokktConfig networkModel:(NetworkModel *)networkModel presentingViewController:(UIViewController *)viewController
{
    NSLog(@"%@ is initialised", networkType);
    self.pokktConfig = pokktConfig;
    
    self.networkModel  =networkModel;
    
    NSString * appId = [networkModel.customData objectForKey:@"appId"];
    
    NSString * appSignature = [networkModel.customData objectForKey:@"appSignature"];
    
    [Chartboost startWithAppId:appId appSignature:appSignature delegate:self];
    
    self.isVideoCached = NO;
    self.isTimedout = NO;
}

- (void)cacheVideo
{
    if (self.isVideoCached)
    {
        NSLog(@"%@ video cached previously", networkType);

        self.isVideoCached = NO;
        
        [PokktNetworkDelegate didFinishedVideoDownload:self.pokktConfig
                                          networkModel:self.networkModel
                                           rewardValue:0 downLoadTime:@""];
    }
    else
    {
        NSLog(@"%@ video caching started", networkType);

        self.isTimedout = NO;
        
        int cacheTimeoutInterval = [PokktManager getCachingTimeoutDuration:self.networkModel];
        
        [Chartboost cacheRewardedVideo:CBLocationMainMenu];
        
        self.cacheTimer = [NSTimer scheduledTimerWithTimeInterval:cacheTimeoutInterval target:self selector:@selector(updateTimer) userInfo:nil repeats:NO];
    }
}

- (void)playVideo
{
    NSLog(@"%@ play video called", networkType);

    [Chartboost showRewardedVideo:CBLocationMainMenu];
}


- (void)updateTimer
{
    if (self.cacheTimer)
    {
        NSLog(@"%@ video caching timed out", networkType);

        [self.cacheTimer invalidate];
        self.cacheTimer = nil;
        self.isTimedout = YES;
        
        [PokktNetworkDelegate didFailedVideoDownload:self.pokktConfig networkModel:self.networkModel errorMessage:@"timed out"];
    }
}

#pragma mark -
#pragma mark - Chartboost delegates
#pragma mark -


/*
 * Chartboost Delegate Methods
 *
 */
- (BOOL)shouldDisplayRewardedVideo:(CBLocation)location;
{
    return TRUE;
}


- (void)didCacheRewardedVideo:(CBLocation)location
{
    if (self.isTimedout)
    {
        NSLog(@"%@ video caching successful after timeout", networkType);

        self.isVideoCached = YES;
    }
    else
    {
        self.isVideoCached = NO;

        NSLog(@"%@ video caching successful before timeout", networkType);

        [self.cacheTimer invalidate];
        self.cacheTimer = nil;
        
        [PokktNetworkDelegate didFinishedVideoDownload:self.pokktConfig networkModel:self.networkModel rewardValue:0 downLoadTime:@""];
    }
}

/*
 * didCompleteRewardedVideo
 *
 * This is called when a rewarded video has been viewed
 *
 * Is fired on:
 * - Rewarded video completed view
 *
 */

- (void)didCompleteRewardedVideo:(CBLocation)location withReward:(int)reward
{
    NSLog(@"%@ video completed", networkType);

    NSLog(@"completed rewarded video view at location %@ with reward amount %d", location, reward);
    
    [PokktNetworkDelegate onVideoCompleted:self.pokktConfig networkModel:self.networkModel];
    
    [PokktNetworkDelegate onVideoGratified:self.pokktConfig networkModel:self.networkModel rewardPoint:reward];
    
}

/*
 * didFailToLoadRewardedVideo
 *
 * This is called when a Rewarded Video has failed to load. The error enum specifies
 * the reason of the failure
 */

- (void)didFailToLoadRewardedVideo:(NSString *)location withError:(CBLoadError)error
{
    NSString *str;
    switch(error){
        case CBLoadErrorInternetUnavailable: {
            str = @"Failed to load Rewarded Video, no Internet connection !";
        } break;
        case CBLoadErrorInternal: {
            str = @"Failed to load Rewarded Video, internal error !";
        } break;
        case CBLoadErrorNetworkFailure: {
            str = @"Failed to load Rewarded Video, network error !";
        } break;
        case CBLoadErrorWrongOrientation: {
            str = @"Failed to load Rewarded Video, wrong orientation !";
        } break;
        case CBLoadErrorTooManyConnections: {
            str = @"Failed to load Rewarded Video, too many connections !";
        } break;
        case CBLoadErrorFirstSessionInterstitialsDisabled: {
            str = @"Failed to load Rewarded Video, first session !";
        } break;
        case CBLoadErrorNoAdFound : {
            str = @"Failed to load Rewarded Video, no ad found !";
        } break;
        case CBLoadErrorSessionNotStarted : {
            str = @"Failed to load Rewarded Video, session not started !";
        } break;
        case CBLoadErrorNoLocationFound : {
            str = @"Failed to load Rewarded Video, missing location parameter !";
        } break;
        default: {
            str = @"Failed to load Rewarded Video, unknown error !";
        }
    }

    self.isVideoCached = NO;

    if (self.isTimedout)
    {
        NSLog(@"%@ video caching failed after timeout", networkType);
    }
    else
    {
        NSLog(@"%@ video caching failed before timeout", networkType);
        
        [self.cacheTimer invalidate];
        self.cacheTimer = nil;
        
        [PokktNetworkDelegate didFailedVideoDownload:self.pokktConfig networkModel:self.networkModel errorMessage:str];
    }
    
    
}

/*!
 @abstract
 Called after a InPlay has attempted to load from the Chartboost API
 servers but failed.
 
 @param location The location for the Chartboost impression type.
 
 @param error The reason for the error defined via a CBLoadError.
 
 @discussion Implement to be notified of when an InPlay has attempted to load from the Chartboost API
 servers but failed for a given CBLocation.
 */
- (void)didFailToLoadInPlay:(CBLocation)location
                  withError:(CBLoadError)error {
    
    NSString *errorString = @"";
    switch(error){
        case CBLoadErrorInternetUnavailable: {
            errorString = @"Failed to load In Play, no Internet connection !";
        } break;
        case CBLoadErrorInternal: {
            errorString = @"Failed to load In Play, internal error !";
        } break;
        case CBLoadErrorNetworkFailure: {
            errorString = @"Failed to load In Play, network errorString !";
        } break;
        case CBLoadErrorWrongOrientation: {
            errorString = @"Failed to load In Play, wrong orientation !";
        } break;
        case CBLoadErrorTooManyConnections: {
            errorString = @"Failed to load In Play, too many connections !";
        } break;
        case CBLoadErrorFirstSessionInterstitialsDisabled: {
            errorString = @"Failed to load In Play, first session !";
        } break;
        case CBLoadErrorNoAdFound : {
            errorString = @"Failed to load In Play, no ad found !";
        } break;
        case CBLoadErrorSessionNotStarted : {
            errorString = @"Failed to load In Play, session not started !";
        } break;
        case CBLoadErrorNoLocationFound : {
            errorString = @"Failed to load In Play, missing location parameter !";
        } break;
        default: {
            errorString = @"Failed to load In Play, unknown error !";
        }
    }
    
    NSLog(@"%@ video download failed", networkType);
    
    self.isVideoCached = NO;
    
    if (self.isTimedout)
    {
        NSLog(@"%@ video caching failed after timeout", networkType);
    }
    else
    {
        NSLog(@"%@ video caching failed before timeout", networkType);
        
        [self.cacheTimer invalidate];
        self.cacheTimer = nil;
        
        [PokktNetworkDelegate didFailedVideoDownload:self.pokktConfig networkModel:self.networkModel errorMessage:errorString];
    }


}

- (void)didCloseRewardedVideo:(CBLocation)location
{
    [PokktNetworkDelegate onVideoClosed:self.pokktConfig networkModel:self.networkModel];
}

- (void)didDisplayRewardedVideo:(CBLocation)location
{
    [PokktNetworkDelegate onVideoDisplayed:self.pokktConfig networkModel:self.networkModel];
}

@end
