//
//  TapjoyNetwork.m
//  SampleApp
//
//  Created by Subhendu Sekhar Sahu on 16/11/15.
//  Copyright © 2015 Pokkt. All rights reserved.
//

#import "TapjoyNetwork.h"
#import "PokktNetworkDelegate.h"
#import "PokktManager.h"


@implementation TapjoyNetwork

static NSString *networkType = @"TapJoy";

- (instancetype)init
{
    self = [super init];
    if (self)
    {
        
    }
    return self;
}

- (void) initNetwork:(PokktConfig *)pokktConfig networkModel:(NetworkModel *)networkModel
                                    presentingViewController:(UIViewController *)viewController
{
    NSLog(@"[TAP-JOY-POKKT] %@ is initialised", networkType);

    self.pokktConfig = pokktConfig;
    
    self.networkModel  =networkModel;
    
    self.viewController = viewController;
    
    [[NSNotificationCenter defaultCenter] addObserver:self
                                             selector:@selector(tjcConnectSuccess:)
                                                 name:TJC_CONNECT_SUCCESS
                                               object:nil];
    
    [[NSNotificationCenter defaultCenter] addObserver:self
                                             selector:@selector(tjcConnectFail:)
                                                 name:TJC_CONNECT_FAILED
                                               object:nil];
    
    NSString * sdkKey = [networkModel.customData objectForKey:@"sdkKey"];
    
    self.placementName = [networkModel.customData objectForKey:@"placement_name"];
    
    //Tapjoy connect call
    [Tapjoy connect:sdkKey];
    
    [Tapjoy setVideoAdDelegate:self];
    [Tapjoy setViewDelegate:self];
    
    self.isVideoCached = NO;
    self.isTimedout = NO;
}

- (void)cacheVideo
{
    [Tapjoy getCurrencyBalanceWithCompletion:^(NSDictionary *parameters, NSError *error)
     {
         if (error)
         {
             NSLog(@"[TAP-JOY-POKKT] Error in getCurrencybalance in Tapjoy caching time %@", error.description);
         }
         else
         {
             self.currentCurrencyBalance = [parameters[@"amount"] intValue];
             NSLog(@"[TAP-JOY-POKKT] Current Balance While caching %d", self.currentCurrencyBalance);

         }
     }];
    
    if (self.isVideoCached)
    {
        NSLog(@"[TAP-JOY-POKKT] %@ video cached previously", networkType);

        self.isVideoCached = NO;
        
        [PokktNetworkDelegate didFinishedVideoDownload:self.pokktConfig
                                          networkModel:self.networkModel
                                           rewardValue:0 downLoadTime:@""];
    }
    else
    {
        NSLog(@"[TAP-JOY-POKKT] %@ video caching started", networkType);

        self.isTimedout = NO;
        
        int cacheTimeoutInterval = [PokktManager getCachingTimeoutDuration:self.networkModel];
        
        TJPlacement *p = [TJPlacement placementWithName:self.placementName delegate:self ];
        [p requestContent];
        
        self.cacheTimer = [NSTimer scheduledTimerWithTimeInterval:cacheTimeoutInterval
                                                           target:self
                                                         selector:@selector(updateTimer)
                                                         userInfo:nil repeats:NO];
    }
}

- (void)playVideo
{
    NSLog(@"[TAP-JOY-POKKT] %@ play video called", networkType);

    [self.placement showContentWithViewController: self.viewController];
}

- (void)updateTimer
{
    if (self.cacheTimer)
    {
        NSLog(@"[TAP-JOY-POKKT] %@ video caching timed out", networkType);

        [self.cacheTimer invalidate];
        self.cacheTimer = nil;
        self.isTimedout = YES;
        
        [PokktNetworkDelegate didFailedVideoDownload:self.pokktConfig networkModel:self.networkModel errorMessage:@"timed out"];
    }
}


-(void)tjcConnectSuccess:(NSNotification*)notifyObj
{
    NSLog(@"[TAP-JOY-POKKT] Tapjoy connect Succeeded");
}

-(void)tjcConnectFail:(NSNotification*)notifyObj
{
    NSLog(@"[TAP-JOY-POKKT] Tapjoy connect Failed");
}


#pragma mark Tapjoy View Delegate Methods

- (void)viewWillAppearWithType:(int)viewType
{
    NSLog(@"[TAP-JOY-POKKT] Tapjoy view is about to be shown. %d", viewType);
}

- (void)viewDidAppearWithType:(int)viewType
{
    NSLog(@"[TAP-JOY-POKKT] Tapjoy view has been shown. %d", viewType);
    // Best Practice: We recommend calling getCurrencyBalance as often as possible so the user’s balance is always up-to-date.
    [Tapjoy getCurrencyBalance];
}

- (void)viewWillDisappearWithType:(int)viewType
{
    NSLog(@"[TAP-JOY-POKKT] Tapjoy view is about to go away. %d", viewType);
}

- (void)viewDidDisappearWithType:(int)viewType
{
    NSLog(@"[TAP-JOY-POKKT] Tapjoy view has been closed. %d", viewType);
    // Best Practice: We recommend calling getCurrencyBalance as often as possible so the user’s balance is always up-to-date.
   // [Tapjoy getCurrencyBalance];
    
    [Tapjoy getCurrencyBalanceWithCompletion:^(NSDictionary *parameters, NSError *error)
     {
         if (error)
             NSLog(@"[TAP-JOY-POKKT] Error in getCurrencybalance in Tapjoy %@", error.description);
         else
         {
             int currentAmount = [parameters[@"amount"] intValue];
             
             NSLog(@"[TAP-JOY-POKKT] Current Balance While Disappearing %d", self.currentCurrencyBalance);

             
             int reward = currentAmount - self.currentCurrencyBalance;
             
             [PokktNetworkDelegate onVideoGratified:self.pokktConfig networkModel:self.networkModel rewardPoint:reward];
         }
     }];

}

#pragma mark Tapjoy Video

- (void)videoAdCompleted
{
    NSLog(@"[TAP-JOY-POKKT]  %@ videoAdCompleted", networkType);
    [PokktNetworkDelegate onVideoCompleted:self.pokktConfig networkModel:self.networkModel];
    
}

#pragma mark TJPlacementDelegate methods

- (void)requestDidSucceed:(TJPlacement*)placement
{
    NSLog(@"[TAP-JOY-POKKT] %@", [NSString stringWithFormat : @"Tapjoy request content complete, isContentAvailable:%d", placement.isContentAvailable]);
    
    if (placement.isContentAvailable == 0)
    {
        self.isVideoCached = NO;

        if (self.isTimedout)
        {
            NSLog(@"[TAP-JOY-POKKT] %@ video caching failed after timeout", networkType);
            
        }
        else
        {
            NSLog(@"[TAP-JOY-POKKT] %@ video download failed", networkType);
            
            [PokktNetworkDelegate didFailedVideoDownload:self.pokktConfig
                                            networkModel:self.networkModel
                                            errorMessage:@"placement content is not available"];
            
        }
    }
}

- (void)contentIsReady:(TJPlacement*)placement
{
    self.placement = placement;
    
    if (self.isTimedout)
    {
        NSLog(@"[TAP-JOY-POKKT] %@ video caching successful after timeout", networkType);

        self.isVideoCached = YES;
    }
    else
    {
        self.isVideoCached = NO;
        NSLog(@"[TAP-JOY-POKKT] %@ video caching successful before timeout", networkType);

        [self.cacheTimer invalidate];
        self.cacheTimer = nil;
        
        [PokktNetworkDelegate didFinishedVideoDownload:self.pokktConfig networkModel:self.networkModel rewardValue:0 downLoadTime:@""];
    }
}

- (void)requestDidFail:(TJPlacement*)placement error:(NSError *)error
{
    self.isVideoCached = NO;
    if (self.isTimedout)
    {
        NSLog(@"[TAP-JOY-POKKT] %@ video caching failed after timeout", networkType);
    }
    else if (placement.isContentAvailable == 0)
    {
        NSLog(@"[TAP-JOY-POKKT] %@ video download failed", networkType);
        
        [PokktNetworkDelegate didFailedVideoDownload:self.pokktConfig
                                        networkModel:self.networkModel
                                        errorMessage:error.description];
    }
}

- (void)contentDidAppear:(TJPlacement*)placement
{
    [PokktNetworkDelegate onVideoDisplayed:self.pokktConfig networkModel:self.networkModel];
    
    NSLog(@"[TAP-JOY-POKKT] Content did appear for %@ placement", [placement placementName]);
}

- (void)contentDidDisappear:(TJPlacement*)placement
{
    [PokktNetworkDelegate onVideoClosed:self.pokktConfig networkModel:self.networkModel];

    NSLog(@"[TAP-JOY-POKKT] Content did disappear for %@ placement", [placement placementName]);
}

@end
