//
//  PokktCocosConfig.cpp
//  Cocos2dxV2xPlugin
//
//  Created by SWARAJ on 16/06/15.
//
//

#include "PokktCocosConfig.h"
#include "PokktNativeExtension.h"


std::string to_string(int value)
{
    std::ostringstream os ;
    os << value ;
    return os.str() ;
}

static std::string getIntegrationTypeString(PokktCocosConfig::PokktIntegrationType integrationType)
{
    switch (integrationType)
    {
        case PokktCocosConfig::INTEGRATION_TYPE_ALL: return "0";
        case PokktCocosConfig::INTEGRATION_TYPE_OFFERWALL: return "1";
        case PokktCocosConfig::INTEGRATION_TYPE_VIDEO: return "2";
    }
    return "0";
}

// Constructor
PokktCocosConfig::PokktCocosConfig()
{
    securityKey = "";
    applicationId = "";
    integrationType = INTEGRATION_TYPE_ALL;
    autoCacheVideo = true;
    thirdPartyUserId = "";
    
    // offer wall specific
    offerWallAssetValue = "";
    closeOnSuccessFlag = false;
    
    // video campaign specific
    skipEnabled = false;
    defaultSkipTime = 0;
    customSkipMessage = "";
    screenName = "Default";
    incentivised = true;
    backButtonDisabled = false;
    retryDuration = 0;
}

// Common Methods

void PokktCocosConfig::setSecurityKey(std::string securityKey)
{
    this->securityKey = securityKey;
    PokktNativeExtension::performOperation(PokktNativeExtension::SetSecurityKey, securityKey);
}
std::string PokktCocosConfig::getSecurityKey()
{
    return this->securityKey;
}

void PokktCocosConfig::setApplicationId(std::string applicationId)
{
    this->applicationId = applicationId;
    PokktNativeExtension::performOperation(PokktNativeExtension::SetApplicationId, applicationId);
}
std::string PokktCocosConfig::getApplicationId()
{
    return this->applicationId;
}

void PokktCocosConfig::setIntegrationType(PokktCocosConfig::PokktIntegrationType integrationType)
{
    this->integrationType = integrationType;
    PokktNativeExtension::performOperation(PokktNativeExtension::SetIntegrationType, ::getIntegrationTypeString(integrationType));
}
PokktCocosConfig::PokktIntegrationType PokktCocosConfig::getIntegrationType()
{
    return this->integrationType;
}

void PokktCocosConfig::setAutoCacheVideo(bool autoCacheVideo)
{
    this->autoCacheVideo = autoCacheVideo;
    PokktNativeExtension::performOperation(PokktNativeExtension::SetAutoCaching, (autoCacheVideo ? "true" : "false"));
}
bool PokktCocosConfig::getAutoCacheVideo()
{
    return this->autoCacheVideo;
}

void PokktCocosConfig::setThirdPartyUserId(std::string thirdPartyUserId)
{
    this->thirdPartyUserId = thirdPartyUserId;
    PokktNativeExtension::performOperation(PokktNativeExtension::SetThirdPartyUserId, thirdPartyUserId);
}
std::string PokktCocosConfig::getThirdPartyUserId()
{
    return this->thirdPartyUserId;
}


// offer wall methods

void PokktCocosConfig::setOfferWallAssetValue(std::string offerWallAssetValue)
{
    this->offerWallAssetValue = offerWallAssetValue;
    //PokktNativeExtension::performOperation(PokktNativeExtension::SetOfferWallAssetValue, offerWallAssetValue);
}
std::string PokktCocosConfig::getOfferWallAssetValue()
{
    return this->offerWallAssetValue;
}

void PokktCocosConfig::setCloseOnSuccessFlag(bool closeOnSuccessFlag)
{
    this->closeOnSuccessFlag = closeOnSuccessFlag;
    PokktNativeExtension::performOperation(PokktNativeExtension::SetCloseOnSuccessFlag, closeOnSuccessFlag ? "true" : "false");
}
bool PokktCocosConfig::getCloseOnSuccessFlag()
{
    return closeOnSuccessFlag;
}

// video methods

void PokktCocosConfig::setSkipEnabled(bool skipEnabled)
{
    this->skipEnabled = skipEnabled;
    PokktNativeExtension::performOperation(PokktNativeExtension::SetSkipEnabled, skipEnabled ? "true" : "false");
}
bool PokktCocosConfig::getSkipEnabled()
{
    return this->skipEnabled;
}

void PokktCocosConfig::setDefaultSkipTime(int defaultSkipTime)
{
    this->defaultSkipTime = defaultSkipTime;
    std::string skipTime = to_string(defaultSkipTime);
    
    PokktNativeExtension::performOperation(PokktNativeExtension::SetDefaultSkipTime, skipTime);
}
int PokktCocosConfig::getDefaultSkipTime()
{
    return this->defaultSkipTime;
}

void PokktCocosConfig::setCustomSkipMessage(std::string customSkipMessage)
{
    this->customSkipMessage = customSkipMessage;
    PokktNativeExtension::performOperation(PokktNativeExtension::SetCustomSkipMessage, customSkipMessage);
}
std::string PokktCocosConfig::getCustomSkipMessage()
{
    return this->customSkipMessage;
}

void PokktCocosConfig::setScreenName(std::string screenName)
{
    this->screenName = screenName;
    //PokktNativeExtension::performOperation(PokktNativeExtension::SetScreenName, screenName);
}
std::string PokktCocosConfig::getScreenName()
{
    return this->screenName;
}

void PokktCocosConfig::setIncentivised(bool incentivised)
{
    this->incentivised = incentivised;
    //PokktNativeExtension::performOperation(PokktNativeExtension::SetIncentivised, incentivised ? "true" : "false");
}
bool PokktCocosConfig::getIncentivised()
{
    return this->incentivised;
}

void PokktCocosConfig::setBackButtonDisabled(bool backButtonDisabled)
{
    this->backButtonDisabled = backButtonDisabled;
    PokktNativeExtension::performOperation(PokktNativeExtension::SetBackButtonDisabled, backButtonDisabled ? "true" : "false");
}
bool PokktCocosConfig::getBackButtonDisabled()
{
    return backButtonDisabled;
}

void PokktCocosConfig::setRetryDuration(int retryDuration)
{
    this->retryDuration = retryDuration;
    std::string durationInString = to_string(retryDuration);
    
    PokktNativeExtension::performOperation(PokktNativeExtension::SetRetryDuration, durationInString);
}
int PokktCocosConfig::getRetryDuration()
{
    return retryDuration;
}

// optional methods

void PokktCocosConfig::setName(std::string name)
{
    this->name = name;
    PokktNativeExtension::performOperation(PokktNativeExtension::SetName,name);
}
std::string PokktCocosConfig::getName()
{
    return this->name;
}

void PokktCocosConfig::setAge(std::string age)
{
    this->age = age;
    PokktNativeExtension::performOperation(PokktNativeExtension::SetAge,age);
}
std::string PokktCocosConfig::getAge()
{
    return this->age;
}

void PokktCocosConfig::setSex(std::string sex)
{
    this->sex = sex;
    PokktNativeExtension::performOperation(PokktNativeExtension::SetSex,sex);
}
std::string PokktCocosConfig::getSex()
{
    return sex;
}

void PokktCocosConfig::setMobileNo(std::string mobileNo)
{
    this->mobileNo = mobileNo;
    PokktNativeExtension::performOperation(PokktNativeExtension::SetMobileNo,mobileNo);
}
std::string PokktCocosConfig::getMobileNo()
{
    return this->mobileNo;
}

void PokktCocosConfig::setEmailAddress(std::string emailAddress)
{
    this->emailAddress = emailAddress;
    PokktNativeExtension::performOperation(PokktNativeExtension::SetEmailAddress,emailAddress);
}
std::string PokktCocosConfig::getEmailAddress()
{
    return this->emailAddress;
}

void PokktCocosConfig::setLocation(std::string location)
{
    this->location = location;
    PokktNativeExtension::performOperation(PokktNativeExtension::SetLocation,location);
}
std::string PokktCocosConfig::getLocation()
{
    return this->location;
}

void PokktCocosConfig::setBirthday(std::string birthday)
{
    this->birthday = birthday;
    PokktNativeExtension::performOperation(PokktNativeExtension::SetBirthday,birthday);
}
std::string PokktCocosConfig::getBirthday()
{
    return birthday;
}

void PokktCocosConfig::setMaritalStatus(std::string maritalStatus)
{
    this->maritalStatus = maritalStatus;
    PokktNativeExtension::performOperation(PokktNativeExtension::SetMaritalStatus,maritalStatus);
}
std::string PokktCocosConfig::getMaritalStatus()
{
    return this->maritalStatus;
}

void PokktCocosConfig::setFacebookId(std::string facebookId)
{
    this->facebookId = facebookId;
    PokktNativeExtension::performOperation(PokktNativeExtension::SetFacebookId,facebookId);
}
std::string PokktCocosConfig::getFacebookId()
{
    return this->facebookId;
}

void PokktCocosConfig::setTwitterHandle(std::string twitterHandle)
{
    this->twitterHandle = twitterHandle;
    PokktNativeExtension::performOperation(PokktNativeExtension::SetTwitterHandle,twitterHandle);
}
std::string PokktCocosConfig::getTwitterHandle()
{
    return this->twitterHandle;
}

void PokktCocosConfig::setEducation(std::string education)
{
    this->education = education;
    PokktNativeExtension::performOperation(PokktNativeExtension::SetEducation,education);
}
std::string PokktCocosConfig::getEducation()
{
    return education;
}

void PokktCocosConfig::setNationality(std::string nationality)
{
    this->nationality = nationality;
    PokktNativeExtension::performOperation(PokktNativeExtension::SetNationality,nationality);
}
std::string PokktCocosConfig::getNationality()
{
    return this->nationality;
}

void PokktCocosConfig::setEmployment(std::string employment)
{
    this->employment = employment;
    PokktNativeExtension::performOperation(PokktNativeExtension::SetEmployment,employment);
}
std::string PokktCocosConfig::getEmployment()
{
    return this->employment;
}

void PokktCocosConfig::setMaturityRating(std::string maturityRating)
{
    this->maturityRating = maturityRating;
    PokktNativeExtension::performOperation(PokktNativeExtension::SetMaturityRating,maturityRating);
}
std::string PokktCocosConfig::getMaturityRating()
{
    return maturityRating;
}

// Analytics Methods

void PokktCocosConfig::setGoogleAnalyticsID(std::string googleAnalyticsID)
{
    this->googleAnalyticsID = maturityRating;
    PokktNativeExtension::performOperation(PokktNativeExtension::SetGoogleAnalyticsId, googleAnalyticsID);
}
std::string PokktCocosConfig::getGoogleAnalyticsID()
{
    return googleAnalyticsID;
}

void PokktCocosConfig::setMixPanelProjectToken(std::string mixPanelProjectToken)
{
    this->mixPanelProjectToken = mixPanelProjectToken;
    PokktNativeExtension::performOperation(PokktNativeExtension::SetMixPanelProjectToken, mixPanelProjectToken);
}
std::string PokktCocosConfig::getMixPanelProjectToken()
{
    return mixPanelProjectToken;
}

void PokktCocosConfig::setFlurryApplicationKey(std::string flurryApplicationKey)
{
    this->flurryApplicationKey = flurryApplicationKey;
    PokktNativeExtension::performOperation(PokktNativeExtension::SetFlurryApplicationKey, flurryApplicationKey);
}
std::string PokktCocosConfig::getFlurryApplicationKey()
{
    return flurryApplicationKey;
}

void PokktCocosConfig::setSelectedAnalyticsType(std::string selectedAnalyticsType)
{
    this->selectedAnalyticsType = selectedAnalyticsType;
    PokktNativeExtension::performOperation(PokktNativeExtension::SetSelectedAnalyticsType, selectedAnalyticsType);
}
std::string PokktCocosConfig::getSelectedAnalyticsType()
{
    return selectedAnalyticsType;
}
