#ifndef __CocosPokktApp__PokktCocosManager__
#define __CocosPokktApp__PokktCocosManager__

#include <stdio.h>
#include <stdlib.h>
#include "cocos2d.h"
#include "PokktNativeExtension.h"
#include "PokktCocosConfig.h"

class PokktCocosManager;

typedef void (cocos2d::CCObject::*EVT_SELECTOR)(std::string);
#define pokkt_event_selector(_SELECTOR) (EVT_SELECTOR)(&_SELECTOR)

#define POKKTLOG(format, ...)      if (PokktCocosManager::_isDebugEnabled) cocos2d::CCLog(format, ##__VA_ARGS__)

class PokktCocosManager
{
    friend class PokktNativeExtension;
    
public:

    // events
    static const std::string VideoClosedEvent;
    static const std::string VideoDisplayedEvent;
    static const std::string VideoSkippedEvent;
    static const std::string VideoCompletedEvent;
    static const std::string VideoGratifiedEvent;
    static const std::string DownloadCompletedEvent;
    static const std::string DownloadFailedEvent;
    static const std::string CoinResponseEvent;
    static const std::string CoinResponseWithTransIdEvent;
    static const std::string CoinResponseFailedEvent;
    static const std::string CampaignAvailabilityEvent;
    static const std::string OfferwallClosedEvent;
    
    // common methods
    static void initPokkt();
    static void setDebug(bool value);
    static bool getDebug();
    static void showLog(std::string message);
    static void showToast(std::string message);
    static void exportLog();
    static void sendAppInfo();
    
    // session methods
    static void startSession();
    static void endSession();
    
    // offerwall methods
    static void getCoins(PokktCocosConfig *pokktCocosConfig);
    static void getPendingCoins();
    static void checkOfferWallCampaign();
    
    // video methods
    static void getVideo(PokktCocosConfig *pokktCocosConfig);
    static void getVideoNonIncent(PokktCocosConfig *pokktCocosConfig);
    static void cacheVideoCampaign();
    static bool isVideoAvailable();
    static double getVideoVc();
    
    // optional methods
    static std::string getVersion();
    
    ~PokktCocosManager(){}
    
//protected:
    
    // handles messages coming from native pokkt runtime
    static void handleNativeMessage(std::string operation, std::string param);
    
    // sets a listener for an event (only one listener per event
    static void setListener(std::string eventName, EVT_SELECTOR listener, cocos2d::CCObject *target);
    static void removeListener(std::string eventName);
    
private:
    
    typedef struct __listenerTargetPair
    {
        EVT_SELECTOR listener;
        cocos2d::CCObject *target;
    }ListenerTargetPair;
    
    
    static bool _isDebugEnabled;
    
    static std::map<std::string, ListenerTargetPair*> _eventMap;
};

#endif /* defined(__CocosPokktApp__PokktCocosManager__) */
