#ifndef __CocosPokktApp__PokktNativeExtension__
#define __CocosPokktApp__PokktNativeExtension__

#include <stdio.h>
#include <stdlib.h>
#include "cocos2d.h"

#if (CC_TARGET_PLATFORM == CC_PLATFORM_IOS)
#include "IOSExtension.h"
#endif

class PokktNativeExtension
{
    friend class PokktCocosManager;
    friend class PokktCocosConfig;
    
public:
    
    typedef enum __pokktOperations
    {
        // Utility Methods
        SetDebug,
        ShowLog,
        ShowToast,
        ExportLog,
        SetThirdPartyUserId,
        
        // Essential Methods
        SetSecurityKey,
        SetApplicationId,
        SetIntegrationType,
        SetAutoCaching,
        InitPokkt,
        SendAppInfo,
        
        // Session Methods
        StartSession,
        EndSession,
        
        // Offerwall Methods
        SetCloseOnSuccessFlag,
        GetCoins,
        GetPendingCoins,
        CheckOfferWallCampaign,
        
        // Video Methods
        GetVideo,
        GetVideoNonIncent,
        CacheVideoCampaign,
        SetSkipEnabled,
        SetDefaultSkipTime,
        SetCustomSkipMessage,
        SetBackButtonDisabled,
        SetRetryDuration,
        
        // Optional Methods
        SetName,
        SetAge,
        SetSex,
        SetMobileNo,
        SetEmailAddress,
        SetLocation,
        SetBirthday,
        SetMaritalStatus,
        SetFacebookId,
        SetTwitterHandle,
        SetEducation,
        SetNationality,
        SetEmployment,
        SetMaturityRating,
        
        // Analytics Methods
        SetGoogleAnalyticsId,
        SetMixPanelProjectToken,
        SetFlurryApplicationKey,
        SetSelectedAnalyticsType,
    } PokktOperations;
    
protected:
    
#if (CC_TARGET_PLATFORM == CC_PLATFORM_ANDROID)

    static void notifyAndroid(std::string operation, std::string param = "");
    static bool isVideoAvailableOnAndroid();
    static double getVideoVcOnAndroid();
    static std::string getPokktSDKVersionOnAndroid();

#endif
    
    // use this to notify native pokkt runtime
    static void notifyNative(std::string operation, std::string param = "");
    
    // use this to check for video availability
    static bool isVideoAvailable();
    
    // use this to get the coin associated
    static double getVideoVc();
    
    // generic
    static void performOperation(PokktOperations operation, std::string param = "");
    
    // sdk version
    static std::string getPokktSDKVersion();
    
private:
};

#endif /* defined(__CocosPokktApp__PokktNativeExtension__) */
