#import "PokktCocosManager.h"
#import <Foundation/Foundation.h>
#import "PokktManager.h"
#import "VideoResponse.h"
#import "IOSExtension.h"

// use this to notify the cocos2dx
static void NotifyCocos(const char* operation, const char*  param)
{
    PokktCocosManager::handleNativeMessage(operation, param);
}

PokktConfig *pokktConfig  = [[PokktConfig alloc]init];

@interface IOSExtension:NSObject<PokktDelegate>
@end

@implementation IOSExtension

#pragma mark - Pokkt Delegates

- (void)didFinishedVideoDownload:(BOOL)isFinished
{
    float vc = [PokktManager getVideoVc];
    NotifyCocos(PokktCocosManager::DownloadCompletedEvent.c_str(), [[NSString stringWithFormat:@"%@", [[NSNumber numberWithFloat:vc] stringValue]] UTF8String]);
}

- (void)didFailedVideoDownload:(NSString *)error
{
    NotifyCocos(PokktCocosManager::DownloadFailedEvent.c_str(), [[NSString stringWithFormat:@"%@", error] UTF8String]);
}

- (void)onVideoCompleated:(BOOL)isCompleated
{
    NotifyCocos(PokktCocosManager::VideoCompletedEvent.c_str(), "Video is completed");
}

- (void)onVideoDisplayed
{
    NotifyCocos(PokktCocosManager::VideoDisplayedEvent.c_str(), "Video is displayed");
}

- (void)onVideoClosed
{
    NotifyCocos(PokktCocosManager::VideoClosedEvent.c_str(), "Video is closed");
}

- (void)onVideoGratified:(VideoResponse *)videoResponse
{
    NotifyCocos(PokktCocosManager::VideoGratifiedEvent.c_str(), [[NSString stringWithFormat:@"%@", videoResponse.coins] UTF8String]);
}

- (void)onVideoSkipped
{
    NotifyCocos(PokktCocosManager::VideoSkippedEvent.c_str(), "Video is skipped");
}

void playVideo(bool incentivised, NSString *screenName)
{
    // set the view controller
    UIViewController *viewController = [[[UIApplication sharedApplication] keyWindow] rootViewController];
    [PokktManager setPresentView:viewController];
    pokktConfig.screenName = screenName;
    pokktConfig.incentivised = incentivised;
    [PokktManager playVideoCampaign:pokktConfig];
}

void notifyIOS(const char* operation, const char* param)
{
    NSString *operationNSStr = [NSString stringWithUTF8String:(operation)];
    NSString *paramNSStr = [NSString stringWithUTF8String:(param)];
    
    
    // Utility Methods
    [operationNSStr isEqualToString:@""];
    if ([operationNSStr isEqualToString:@"setDebug"])
    {
        BOOL debug = [paramNSStr isEqualToString:@"true"];
        [PokktManager setDebug:debug];
    }
    
    else if ([operationNSStr isEqualToString:@"showLog"])
        NSLog(@"ShowLog is not supported by the iOS Plugin.");
    
    else if ([operationNSStr isEqualToString:@"showToast"])
        NSLog(@"ShowToast is not supported by the iOS Plugin.");
    
    else if ([operationNSStr isEqualToString:@"exportLog"])
    {
        // set the view controller
        UIViewController *viewController = [[[UIApplication sharedApplication] keyWindow] rootViewController];
        [PokktManager setPresentView:viewController];
        [PokktManager exportPokktSDKLog];
    }
    
    else if ([operationNSStr isEqualToString:@"setThirdPartyUserId"])
        pokktConfig.thirdPartyUserId = paramNSStr;
    
    
    // Essential Methods
    
    else if ([operationNSStr isEqualToString:@"setSecurityKey"])
        [pokktConfig setSecurityKey:[NSString stringWithUTF8String:param]];//pokktConfig.securityKey = paramNSStr;
    
    else if ([operationNSStr isEqualToString:@"setApplicationId"])
        [pokktConfig setApplicationId:[NSString stringWithUTF8String:param]];//pokktConfig.applicationId = paramNSStr;
    
    else if ([operationNSStr isEqualToString:@"setAutoCaching"])
        pokktConfig.autoCacheVideo = [paramNSStr boolValue];
    
    else if ([operationNSStr isEqualToString:@"setIntegrationType"])
        NSLog(@"setIntegrationType is not needed for IOS.");
    
    else if ([operationNSStr isEqualToString:@"initPokkt"])
    {
        // set the view controller
        UIViewController *viewController = [[[UIApplication sharedApplication] keyWindow] rootViewController];
        [PokktManager setPresentView:viewController];
        
        // initialize pokkt
        [PokktManager initPokkt:pokktConfig];
        
        IOSExtension *ext = [[IOSExtension alloc] init];
        [PokktManager setPokktDelegate:ext];
    }
    
    else if ([operationNSStr isEqualToString:@"sendAppInfo"])
        [PokktManager appInstallFirstTime];
    
    
    // Session Methods
    
    else if ([operationNSStr isEqualToString:@"startSession"])
        [PokktManager startSession:pokktConfig];
    
    else if ([operationNSStr isEqualToString:@"endSession"])
        [PokktManager endSession];
    
    
    // OfferWall Methods -- NOT Supported in iOS Plugin  -- should go to default log case.
    
    
    // Video Methods
    
    else if ([operationNSStr isEqualToString:@"getVideo"])
        playVideo(YES, paramNSStr);
    
    else if ([operationNSStr isEqualToString:@"getVideoNonIncent"])
        playVideo(NO, paramNSStr);
    
    else if ([operationNSStr isEqualToString:@"cacheVideoCampaign"])
        [PokktManager cacheVideoCampaign:pokktConfig];
    
    else if ([operationNSStr isEqualToString:@"setSkipEnabled"])
        pokktConfig.skipEnabled = [paramNSStr isEqualToString:@"true"];
    
    else if ([operationNSStr isEqualToString:@"setDefaultSkipTime"])
        pokktConfig.defaultSkipTime = [paramNSStr intValue];
    
    else if ([operationNSStr isEqualToString:@"setCustomSkipMessage"])
        pokktConfig.customSkipMessage = paramNSStr;
    
    else if ([operationNSStr isEqualToString:@"setBackButtonDisabled"])
        NSLog(@"setBackButtonDisabled is not supported by the iOS Plugin.");
    
    else if ([operationNSStr isEqualToString:@"setRetryDuration"])
        pokktConfig.retryDuration = [paramNSStr intValue];
    
    
    // Common Methods
    
    else if ([operationNSStr isEqualToString:@"setName"])
        pokktConfig.name = paramNSStr;
    
    else if ([operationNSStr isEqualToString:@"setAge"])
        pokktConfig.age = paramNSStr;
    
    else if ([operationNSStr isEqualToString:@"setSex"])
        pokktConfig.sex = paramNSStr;
    
    else if ([operationNSStr isEqualToString:@"setMobileNo"])
        pokktConfig.mobileNo = paramNSStr;
    
    else if ([operationNSStr isEqualToString:@"setEmailAddress"])
        pokktConfig.emailAddress = paramNSStr;
    
    else if ([operationNSStr isEqualToString:@"setLocation"])
        pokktConfig.location = paramNSStr;
    
    else if ([operationNSStr isEqualToString:@"setBirthday"])
        pokktConfig.birthday = paramNSStr;
    
    else if ([operationNSStr isEqualToString:@"setMaritalStatus"])
        pokktConfig.maritalStatus = paramNSStr;
    
    else if ([operationNSStr isEqualToString:@"setFacebookId"])
        pokktConfig.facebookId = paramNSStr;
    
    else if ([operationNSStr isEqualToString:@"setTwitterHandle"])
        pokktConfig.twitterHandle = paramNSStr;
    
    else if ([operationNSStr isEqualToString:@"setEducation"])
        pokktConfig.education = paramNSStr;
    
    else if ([operationNSStr isEqualToString:@"setNationality"])
        pokktConfig.nationality = paramNSStr;
    
    else if ([operationNSStr isEqualToString:@"setEmployment"])
        pokktConfig.employment = paramNSStr;
    
    else if ([operationNSStr isEqualToString:@"setMaturityRating"])
        pokktConfig.maturityRating = paramNSStr;
    
    
    // Analytics Methods
    
    else if ([operationNSStr isEqualToString:@"googleAnalyticsID"])
        pokktConfig.googleTrackerID = paramNSStr;
    
    else if ([operationNSStr isEqualToString:@"mixPanelProjectToken"])
        pokktConfig.mixPanelTrackerID = paramNSStr;
    
    else if ([operationNSStr isEqualToString:@"flurryApplicationKey"])
        pokktConfig.flurryTrackerID = paramNSStr;
    
    else if ([operationNSStr isEqualToString:@"selectedAnalyticsType"])
    {
        if ([paramNSStr isEqualToString:@"FLURRY"])
            pokktConfig.eventType = FLURRY_ANALYTICS;
        
        else if ([paramNSStr isEqualToString:@"GOOGLE_ANALYTICS"])
            pokktConfig.eventType = GOOGLE_ANALYTICS;
        
        else if ([paramNSStr isEqualToString:@"MIXPANNEL"])
            pokktConfig.eventType = MIXPANNEL_ANALYTICS;
    }
    
    else
        NSLog(@"Operation %s is not supported by the iOS Plugin.", operation);
}

bool isVideoAvailableOnIOS()
{
    return [PokktManager isVideoAvailable];
}

double getVideoVcOnIOS()
{
    return [PokktManager getVideoVc];
}

const char* getPokktSDKVersionInIOS()
{
    const char* version = [[NSString stringWithFormat:@"%@", [PokktManager getSDKVersion]] UTF8String];
    return version;
}

@end
