#include "PokktNativeExtension.h"
#include "PokktCocosManager.h"

/**
 HANDLES NATIVE ANDROID MESSAGES
 */
#if (CC_TARGET_PLATFORM == CC_PLATFORM_ANDROID)

#include "platform/android/jni/JniHelper.h"

#ifdef __cplusplus
extern "C"
{
#endif
    
    void Java_com_pokkt_cocos2dx_PokktNativeExtension_NotifyCPP(JNIEnv* env, jobject thiz, jstring operation, jstring param)
    {
        std::string operationString = cocos2d::JniHelper::jstring2string(operation);
        std::string paramString = cocos2d::JniHelper::jstring2string(param);
        
        PokktCocosManager::handleNativeMessage(operationString, paramString);
        
        env->DeleteLocalRef(operation);
        env->DeleteLocalRef(param);
    }
    
#ifdef __cplusplus
};
#endif

#endif /* if (CC_TARGET_PLATFORM == CC_PLATFORM_ANDROID) */

#if (CC_TARGET_PLATFORM == CC_PLATFORM_ANDROID)

void PokktNativeExtension::notifyAndroid(std::string operation, std::string param)
{
    POKKTLOG("[POKKT-CPP] notifying android of operation: %s, param: %s", operation.c_str(), param.c_str());
    
    cocos2d::JniMethodInfo methodInfo;
    if (!cocos2d::JniHelper::getStaticMethodInfo(methodInfo,
                                                 "com/pokkt/cocos2dx/PokktNativeExtension",
                                                 "NotifyAndroid",
                                                 "(Ljava/lang/String;Ljava/lang/String;)V"))
        return;
    
    jstring joperation = methodInfo.env->NewStringUTF(operation.c_str());
    jstring jparam = methodInfo.env->NewStringUTF(param.c_str());
    methodInfo.env->CallStaticVoidMethod(methodInfo.classID, methodInfo.methodID, joperation, jparam);
    
    methodInfo.env->DeleteLocalRef(methodInfo.classID);
    methodInfo.env->DeleteLocalRef(joperation);
    methodInfo.env->DeleteLocalRef(jparam);
}

bool PokktNativeExtension::isVideoAvailableOnAndroid()
{
    POKKTLOG("[POKKT-CPP] checking for video availability on android device...");
    
    cocos2d::JniMethodInfo methodInfo;
    if (!cocos2d::JniHelper::getStaticMethodInfo(methodInfo,
                                                 "com/pokkt/cocos2dx/PokktNativeExtension",
                                                 "isVideoAvailableOnAndroid",
                                                 "()Z"))
        return false;
    
    jboolean jresult = methodInfo.env->CallStaticBooleanMethod(methodInfo.classID, methodInfo.methodID);
    bool result = (bool)jresult;
    
    methodInfo.env->DeleteLocalRef(methodInfo.classID);
    
    POKKTLOG(result ? "[POKKT-CPP] video found on android deivce!" : "[POKKT-CPP] video not available on android deivce!");
    
    return result;
}

double PokktNativeExtension::getVideoVcOnAndroid()
{
    POKKTLOG("[POKKT-CPP] getting video-vc on android device...");
    
    cocos2d::JniMethodInfo methodInfo;
    if (!cocos2d::JniHelper::getStaticMethodInfo(methodInfo,
                                                 "com/pokkt/cocos2dx/PokktNativeExtension",
                                                 "getVideoVcOnAndroid",
                                                 "()F"))
        return 0.0f;
    
    jint jresult = methodInfo.env->CallStaticFloatMethod(methodInfo.classID, methodInfo.methodID);
    double result = (double)jresult;
    
    methodInfo.env->DeleteLocalRef(methodInfo.classID);
    
    POKKTLOG("[POKKT-CPP] video-vc on android deivce currently is %f!", result);
    
    return result;
}

std::string PokktNativeExtension::getPokktSDKVersionOnAndroid()
{
    POKKTLOG("[POKKT-CPP] checking for sdk version on android device...");
    
    cocos2d::JniMethodInfo methodInfo;
    if (!cocos2d::JniHelper::getStaticMethodInfo(methodInfo,
                                                 "com/pokkt/cocos2dx/PokktNativeExtension",
                                                 "getPokktSDKVersionOnAndroid",
                                                 "()Ljava/lang/String;"))
        return "not-found";
    
    jstring jresult = (jstring) methodInfo.env->CallStaticObjectMethod(methodInfo.classID, methodInfo.methodID);
    std::string result = cocos2d::JniHelper::jstring2string(jresult);
    
    methodInfo.env->DeleteLocalRef(methodInfo.classID);
    
    POKKTLOG("[POKKT-CPP] sdk version on android deivce currently is %s!", result.c_str());
    
    return result;
}

#endif

void PokktNativeExtension::notifyNative(std::string operation, std::string param)
{
#if (CC_TARGET_PLATFORM == CC_PLATFORM_ANDROID)
    
    notifyAndroid(operation, param);
    
#elif (CC_TARGET_PLATFORM == CC_PLATFORM_IOS)
    
    POKKTLOG("[POKKT-CPP] notifying iOS of operation: %s, param: %s", operation.c_str(), param.c_str());
    notifyIOS(operation.c_str(), param.c_str());
    
#endif
}

bool PokktNativeExtension::isVideoAvailable()
{
#if (CC_TARGET_PLATFORM == CC_PLATFORM_ANDROID)
    
    return isVideoAvailableOnAndroid();
    
#elif (CC_TARGET_PLATFORM == CC_PLATFORM_IOS)
    
    POKKTLOG("[POKKT-CPP] checking for video availability on IOS device...");
    return isVideoAvailableOnIOS();
    
#endif
}

double PokktNativeExtension::getVideoVc()
{
#if (CC_TARGET_PLATFORM == CC_PLATFORM_ANDROID)
    
    return getVideoVcOnAndroid();
    
#elif (CC_TARGET_PLATFORM == CC_PLATFORM_IOS)
    
    POKKTLOG("[POKKT-CPP] getting video-vc on IOS device...");
    return getVideoVcOnIOS();
    
#endif
}

std::string PokktNativeExtension::getPokktSDKVersion()
{
#if (CC_TARGET_PLATFORM == CC_PLATFORM_ANDROID)
    
    return getPokktSDKVersionOnAndroid();
    
#elif (CC_TARGET_PLATFORM == CC_PLATFORM_IOS)
    
    POKKTLOG("[POKKT-CPP] getting sdk version on IOS device...");
    return getPokktSDKVersionInIOS();
    
#endif
}

void PokktNativeExtension::performOperation(PokktOperations operation, std::string param)
{
    switch (operation)
    {
        // utility methods
        case SetDebug:					notifyNative("setDebug",				param); break;
        case ShowLog:					notifyNative("showLog",					param); break;
        case ShowToast:					notifyNative("showToast",				param); break;
        case ExportLog:					notifyNative("exportLog",				param); break;
        case SetThirdPartyUserId:		notifyNative("setThirdPartyUserId",		param); break;
            
        // essential methods
        case SetSecurityKey:			notifyNative("setSecurityKey",			param); break;
        case SetApplicationId:			notifyNative("setApplicationId",		param); break;
        case SetIntegrationType:		notifyNative("setIntegrationType",		param); break;
        case SetAutoCaching:			notifyNative("setAutoCaching",			param); break;
        case InitPokkt:					notifyNative("initPokkt",				param); break;
        case SendAppInfo:				notifyNative("sendAppInfo",				param); break;
            
        // session methods
        case StartSession:       		notifyNative("startSession",     		param); break;
        case EndSession:       			notifyNative("endSession",     			param); break;
            
        // offerwall methods
        case SetCloseOnSuccessFlag:     notifyNative("setCloseOnSuccessFlag",   param); break;
        case GetCoins:              	notifyNative("getCoins",            	param); break;
        case GetPendingCoins:           notifyNative("getPendingCoins",     	param); break;
        case CheckOfferWallCampaign:    notifyNative("checkOfferWallCampaign",  param); break;
            
        // video methods
        case GetVideo:                  notifyNative("getVideo",            	param); break;
        case GetVideoNonIncent:    		notifyNative("getVideoNonIncent",   	param); break;
        case CacheVideoCampaign:        notifyNative("cacheVideoCampaign",      param); break;
        case SetSkipEnabled:          	notifyNative("setSkipEnabled",        	param); break;
        case SetDefaultSkipTime:    	notifyNative("setDefaultSkipTime",      param); break;
        case SetCustomSkipMessage:    	notifyNative("setCustomSkipMessage",    param); break;
        case SetBackButtonDisabled:    	notifyNative("setBackButtonDisabled",   param); break;
        case SetRetryDuration:          notifyNative("setRetryDuration",        param); break;
            
        // optional methods
        case SetName:                   notifyNative("setName",                 param); break;
        case SetAge:                    notifyNative("setAge",              	param); break;
        case SetSex:                    notifyNative("setSex",              	param); break;
        case SetMobileNo:               notifyNative("setMobileNo",             param); break;
        case SetEmailAddress:           notifyNative("setEmailAddress",         param); break;
        case SetLocation:               notifyNative("setLocation",             param); break;
        case SetBirthday:               notifyNative("setBirthday",             param); break;
        case SetMaritalStatus:          notifyNative("setMaritalStatus",        param); break;
        case SetFacebookId:             notifyNative("setFacebookId",           param); break;
        case SetTwitterHandle:          notifyNative("setTwitterHandle",        param); break;
        case SetEducation:          	notifyNative("setEducation",    		param); break;
        case SetNationality:            notifyNative("setNationality",          param); break;
        case SetEmployment:       		notifyNative("setEmployment",     		param); break;
        case SetMaturityRating:         notifyNative("setMaturityRating",       param); break;
            
        // analytics methods
        case SetGoogleAnalyticsId:		notifyNative("setGoogleAnalyticsID",	param); break;
        case SetMixPanelProjectToken:	notifyNative("setMixPanelProjectToken",	param); break;
        case SetFlurryApplicationKey:	notifyNative("setFlurryApplicationKey",	param); break;
        case SetSelectedAnalyticsType:	notifyNative("setSelectedAnalyticsType",param); break;
    }
}
